@@ -1,9 +1,9 @@
 package Sort::Sub::by_perl_function;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-15'; # DATE
+our $DATE = '2020-02-28'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.116'; # VERSION
+our $VERSION = '0.117'; # VERSION
 
 use 5.010;
 use strict;
@@ -75,7 +75,7 @@ Sort::Sub::by_perl_function - Sort by Perl function
 
 =head1 VERSION
 
-This document describes version 0.116 of Sort::Sub::by_perl_function (from Perl distribution Sort-Sub), released on 2019-12-15.
+This document describes version 0.117 of Sort::Sub::by_perl_function (from Perl distribution Sort-Sub), released on 2020-02-28.
 
 =head1 SYNOPSIS
 
@@ -128,7 +128,7 @@ perl::funcname.
 
 bool.
 
-Compare using Perl's <=> instead of cmp.
+Compare using Perl's <=E<gt> instead of cmp.
 
 =head1 HOMEPAGE
 
@@ -156,7 +156,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
